@@ -13,15 +13,13 @@
 ##############################################################################
 """LDAPAdapter tests
 
-$Id: test_field.py 70248 2006-09-20 08:30:10Z dobe $
+$Id: test_field.py 119916 2011-01-25 16:46:10Z faassen $
 """
 __docformat__ = "reStructuredText"
 
 import sys
 
-import unittest
-
-from zope.testing import doctest
+import unittest, doctest
 
 
 def test_suite():
